package com.example.testpay.controller;

import com.alibaba.fastjson.JSONObject;
import com.example.testpay.entity.ResultPayEntity;
import com.example.testpay.utils.ZZFHttpUtils;
import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.methods.PostMethod;
import org.apache.commons.httpclient.params.HttpConnectionManagerParams;
import org.apache.commons.httpclient.params.HttpMethodParams;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.client.utils.URIBuilder;
import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
import org.apache.http.conn.ssl.TrustSelfSignedStrategy;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.ssl.SSLContexts;
import org.apache.http.util.EntityUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.io.BufferedReader;
import java.net.URI;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author xiaowuliu
 * @Version 1.0
 */
@RestController
public class ZZFPayController {


    @RequestMapping(value = "onlinepay", method = {RequestMethod.GET, RequestMethod.POST})
    public String onlinePay(HttpServletRequest request, String price, String name, String paytype) {
        Map<String, String> map = new HashMap<>();
        map.put("price", price);
        map.put("name", name);
        if (paytype != null && paytype.equals("0")) {
            map.put("other", "zzfpage-wxpay");
        } else {
            map.put("other", "zzfpage-alipay");
        }
        CloseableHttpClient httpclient;
        BufferedReader in = null;
        String responseAsString = null;
        try {
            httpclient = HttpClients.custom().setSSLSocketFactory(new SSLConnectionSocketFactory(SSLContexts.custom().loadTrustMaterial(null, new TrustSelfSignedStrategy()).build())).build();
            URIBuilder builder = new URIBuilder(ZZFHttpUtils.CreateOrderURL);
            // 创建URI,可以设置host，设置参数等
            if (map != null) {
                for (String key : map.keySet()) {
                    builder.addParameter(key, map.get(key));
                }
            }
            URI uri = builder.build();
            HttpUriRequest httpGet = new HttpGet(uri);
            httpGet.setHeader("Payment-Key", ZZFHttpUtils.AppKey);
            httpGet.setHeader("Payment-Secret", ZZFHttpUtils.AppSecret);

            CloseableHttpResponse response = httpclient.execute(httpGet);
            responseAsString = EntityUtils.toString(response.getEntity());
            System.out.println("打印：" + responseAsString);
            response.close();
            return responseAsString;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 订单支付状态查询
     */
    @ResponseBody
    @RequestMapping(value = "findOrderState", method = {RequestMethod.GET, RequestMethod.POST})
    public Object findOrderState(String orderId) {
        String res = "";
        HttpClient client = new HttpClient();
        PostMethod postMethod = new PostMethod(ZZFHttpUtils.FindOrderURL);
        postMethod.getParams().setParameter(HttpMethodParams.HTTP_CONTENT_CHARSET, "UTF-8");
        HttpConnectionManagerParams managerParams = client.getHttpConnectionManager().getParams();
        // 设置连接超时时间(单位毫秒)
        managerParams.setConnectionTimeout(5000);
        // 设置读数据超时时间(单位毫秒)
        managerParams.setSoTimeout(5000);
        // 头信息
        postMethod.addRequestHeader("Payment-Key", ZZFHttpUtils.AppKey);
        postMethod.addRequestHeader("Payment-Secret", ZZFHttpUtils.AppSecret);
        postMethod.addParameter("orderId", orderId);
        try {
            System.out.println(postMethod.getURI());
            int code = client.executeMethod(postMethod);
            if (code == 200) {
                //解析站长付返回数据
                //  { "msg": "订单支付完成", "code": "10001", "state": "0" }
                res = postMethod.getResponseBodyAsString();
                System.out.println(res);
            }
        } catch (Exception e) {
            System.out.println("错误：" + e.getMessage());
            e.printStackTrace();
        }
        JSONObject jsonObject = JSONObject.parseObject(res);
        return jsonObject;
    }

    /*
     *  接收站长付发送的通知,数据格式如下
     *   {"code": 10001,"msg": "回调成功","other": "","orderId": "oderpay-445b1306-6f50-48dd-99c1-9a704108f8ff","price": "99.97","originalprice":"100","name": "开通超级VIP","reurl": "","thirduid": "15811111111","paytype": "0","remarks": ""}
     */
    @ResponseBody
    @RequestMapping(value = "/receiveNotify", method = {RequestMethod.GET, RequestMethod.POST})
    public void receiveCallBack(@RequestBody ResultPayEntity resultPay) {
        System.out.println("收到来自站长付的通知：" + resultPay.toString());
        //处理自己的业务逻辑
        //例如开通会员、用户充值等等。。。
    }
}
